@@ -2,7 +2,7 @@
 
 #![no_std]
 
-mod matrix;
+pub mod matrix;
 
 pub fn test(number: u8) -> u8 {
     number
